Struct json_ld_compaction::Options
source · pub struct Options {
pub processing_mode: ProcessingMode,
pub compact_to_relative: bool,
pub compact_arrays: bool,
pub ordered: bool,
}Expand description
Compaction options.
Fields
processing_mode: ProcessingModeJSON-LD processing mode.
compact_to_relative: boolDetermines if IRIs are compacted relative to the provided base IRI or document location when compacting.
compact_arrays: boolIf set to true, arrays with just one element are replaced with that element during compaction.
If set to false, all arrays will remain arrays even if they have just one element.
ordered: boolIf set to true, properties are processed by lexical order.
If false, order is not considered in processing.